==> ejc-jltest-api-3.0.0-20240309.002551-16-sources.jar: com/ejianc/business/jltest/orgtest/vo/MeetingDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 参会人员1
 * 
 * @author generator
 * 
 */
public class MeetingDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long meetingId; // 主表主键ID
    private Long detailEmployeeId; // 参会人员
    private String detailEmployeeName; // 参会人员名称
    private String detailRole; // 职务/部门
    private BigDecimal detailMny; // 薪资
    private String detailMemo; // 备注
    

    public Long getMeetingId() {
        return meetingId;
    }

    public void setMeetingId(Long meetingId) {
        this.meetingId = meetingId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }
    @ReferDeserialTransfer
    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailRole() {
        return detailRole;
    }

    public void setDetailRole(String detailRole) {
        this.detailRole = detailRole;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jltest-api-3.0.0-20240313.072035-72-sources.jar: com/ejianc/business/jltest/orgtest/vo/MeetingDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 参会人员1
 * 
 * @author generator
 * 
 */
public class MeetingDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long meetingId; // 主表主键ID
    private Long detailEmployeeId; // 参会人员
    private String detailEmployeeName; // 参会人员名称
    private String detailRole; // 职务/部门
    private BigDecimal detailMny; // 薪资
    private String detailMemo; // 备注

    private String errorMsg; // 导入错误信息

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    public Long getMeetingId() {
        return meetingId;
    }

    public void setMeetingId(Long meetingId) {
        this.meetingId = meetingId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }
    @ReferDeserialTransfer
    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailRole() {
        return detailRole;
    }

    public void setDetailRole(String detailRole) {
        this.detailRole = detailRole;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
